@@ -19,6 +19,12 @@ Perform Levenberg-Marquardt least-squares minimization, based on MINPACK-1.
     rivers@cars.uchicago.edu
     Updated versions can be found at http://cars.uchicago.edu/software
 
+  2022-09-21 [PAK] add 'double' parameter to select machine precision for
+  the objective function. This mainly affects numerical derivatives, forcing
+  the step size to be large enough that x + h != x, but will also change the
+  criteria for correcting degenerate qr decomposition and maybe stopping
+  conditions and returned status codes.
+
 
                                  DESCRIPTION
 
@@ -135,7 +141,7 @@ Perform Levenberg-Marquardt least-squares minimization, based on MINPACK-1.
     # stop the calculation.
     status = 0
     if (dojac):
-       pderiv = numpy.zeros([len(x), len(p)], numpy.float)
+       pderiv = numpy.zeros([len(x), len(p)], numpy.float64)
        for j in range(len(p)):
          pderiv[:,j] = FGRAD(x, p, j)
     else:
@@ -273,7 +279,7 @@ Perform Levenberg-Marquardt least-squares minimization, based on MINPACK-1.
 
    import mpfit
    import numpy
-   x = numpy.arange(100, numpy.float)
+   x = numpy.arange(100, numpy.float64)
    p0 = [5.7, 2.2, 500., 1.5, 2000.]
    y = ( p[0] + p[1]*[x] + p[2]*[x**2] + p[3]*numpy.sqrt(x) +
          p[4]*numpy.log(x))
@@ -592,7 +598,7 @@ class mpfit:
                 damp=0., maxiter=200, factor=100., nprint=1,
                 iterfunct='default', iterkw={}, nocovar=0,
                 fastnorm=0, rescale=0, autoderivative=1, quiet=0,
-                diag=None, epsfcn=None, debug=0):
+                diag=None, epsfcn=None, debug=0, double=1):
       """
 Inputs:
   fcn:
@@ -745,6 +751,9 @@ Keywords:
       desired in the approximate solution.
       Default: 1E-10
 
+   double:
+      Use double=1 if fcn is double precision or double=0 for single precision. 
+
  Outputs:
 
    Returns an object of type mpfit.  The results are attributes of this class,
@@ -847,7 +856,7 @@ Keywords:
       self.fastnorm = fastnorm
       self.nfev = 0
       self.damp = damp
-      self.machar = machar(double=1)
+      self.machar = machar(double=double)
       machep = self.machar.machep
 
       if (fcn is None):
@@ -888,8 +897,8 @@ Keywords:
             self.errmsg = 'ERROR: either P or PARINFO(*)["value"] must be supplied.'
             return
 
-      ## Make sure parameters are numpy arrays of type numpy.float
-      xall = numpy.asarray(xall, numpy.float)
+      ## Make sure parameters are numpy arrays of type numpy.float64
+      xall = numpy.asarray(xall, numpy.float64)
 
       npar = len(xall)
       self.fnorm  = -1.
@@ -986,8 +995,8 @@ Keywords:
          if (len(wh) > 0): return
          self.errmsg = ''
 
-      # Make sure x is a numpy array of type numpy.float
-      x = numpy.asarray(x, numpy.float)
+      # Make sure x is a numpy array of type numpy.float64
+      x = numpy.asarray(x, numpy.float64)
 
       [self.status, fvec] = self.call(fcn, self.params, functkw)
       if (self.status < 0):
@@ -1320,14 +1329,14 @@ Keywords:
 
             ## Fill in actual covariance matrix, accounting for fixed
             ## parameters.
-            self.covar = numpy.zeros([nn, nn], numpy.float)
+            self.covar = numpy.zeros([nn, nn], numpy.float64)
             for i in range(n):
                indices = ifree+ifree[i]*n
                numpy.put(self.covar, indices, cv[:,i])
 
             ## Compute errors in parameters
             catch_msg = 'computing parameter errors'
-            self.perror = numpy.zeros(nn, numpy.float)
+            self.perror = numpy.zeros(nn, numpy.float64)
             d = numpy.diagonal(self.covar).copy()
             wh, = numpy.nonzero(d >= 0)
             if len(wh) > 0:
@@ -1399,9 +1408,9 @@ Keywords:
       test = default
       if isinstance(default, list): test=default[0]
       if isinstance(test, int):
-         values = numpy.asarray(values, numpy.int)
+         values = numpy.asarray(values, numpy.int32)
       elif isinstance(test, float):
-         values = numpy.asarray(values, numpy.float)
+         values = numpy.asarray(values, numpy.float64)
       return(values)
 
 
@@ -1473,7 +1482,7 @@ Keywords:
       ## Compute analytical derivative if requested
       if (autoderivative == 0):
          mperr = 0
-         fjac = numpy.zeros(nall, numpy.float)
+         fjac = numpy.zeros(nall, numpy.float64)
          numpy.put(fjac, ifree, 1.0)  ## Specify which parameters need derivatives
          [status, fp, pderiv] = self.call(fcn, xall, functkw, fjac=fjac)
 
@@ -1493,7 +1502,7 @@ Keywords:
             fjac.shape = [m, n]
             return(fjac)
 
-      fjac = numpy.zeros([m, n], numpy.float)
+      fjac = numpy.zeros([m, n], numpy.float64)
 
       h = eps * abs(x)
 
@@ -1678,7 +1687,7 @@ Keywords:
       n = sz[1]
 
       ## Compute the initial column norms and initialize arrays
-      acnorm = numpy.zeros(n, numpy.float)
+      acnorm = numpy.zeros(n, numpy.float64)
       for j in range(n):
          acnorm[j] = self.enorm(a[:,j])
       rdiag = acnorm.copy()
